@@ -655,14 +655,14 @@ def do_cmp_vivado_project(ip, deps, sim_job, sub_ip=False, owner_ip=None):
         vlog_compilation_log_path = cfg.sim_dir + "/cmp/" + ip_dir_name + ".viv.vlog.cmp.log"
         vhdl_compilation_log_path = cfg.sim_dir + "/cmp/" + ip_dir_name + ".viv.vhdl.cmp.log"
         vlog_arg_list = [f"-prj {ip.path}/{ip.vproj_vlog}"]
-        vlog_arg_list.append("--work " + work_name + "=" + cmp_out)
+        #vlog_arg_list.append("--work " + work_name + "=" + cmp_out)
         vlog_arg_list += vivado_project_default_vlog_compilation_args
         vlog_arg_list += convert_defines(sim_job)
         vlog_arg_list += convert_compilation_args(sim_job)
         vlog_arg_list += convert_deps_to_args(deps, sim_job)
         vlog_arg_list.append("--log " + vlog_compilation_log_path)
         vhdl_arg_list = [f"-prj {ip.path}/{ip.vproj_vhdl}"]
-        vhdl_arg_list.append("--work " + work_name + "=" + cmp_out)
+        #vhdl_arg_list.append("--work " + work_name + "=" + cmp_out)
         vhdl_arg_list += vivado_project_default_vhdl_compilation_args
         vlog_arg_list += convert_defines(sim_job)
         vlog_arg_list += convert_compilation_args(sim_job)
@@ -707,8 +707,8 @@ def do_elab(ip, sim_job, wd):
         arg_list.append("--log "  + elaboration_log_path)
         arg_list.append("-s "     + ip.name)
         arg_list.append("-L "     + ip.name + "=" + ip_cmp_path)
-        #if ip.has_dut and ip.dut_ip_type == "vivado":
-        #    arg_list.append("-L " + ip.dut.target_ip_model.name)
+        if ip.has_dut and ip.dut_ip_type == "vivado":
+            arg_list.append("-L " + ip.dut.target_ip_model.vproj_name)
         for construct in ip.hdl_src_top_constructs:
             if "." in construct:
                 arg_list.append(construct)
