@@ -169,20 +169,19 @@ def main(sim_job):
             if not sim_job.compile and not sim_job.elaborate and not sim_job.simulate:
                 common.info(f"Done.")
         fsoc_core_name = ip.dut_core
-    elif ip.dut_ip_type != "":
-        if ip.dut_ip_type.target_ip_model.sub_type == "vivado":
-            dut_ip_str = f"{ip.dut.vendor}/{ip.dut.target_ip}"
-            common.info(f"Compiling Vivado Project DUT IP '{dut_ip_str}' ...")
-            est_time = get_ip_cmp_est(ip.dut_ip_type.target_ip_model, sim_job)
-            if est_time > 0:
-                pool = ThreadPool(processes=1)
-                pool.apply_async(progress_bar)
-                eal.cmp_vivado_project(ip.dut.target_ip_model, sim_job)
-                fill_progress_bar()
-                pool.terminate()
-                pool.join()
-            else:
-                eal.cmp_vivado_project(ip.dut.target_ip_model, sim_job)
+    elif ip.dut_ip_type == "vivado":
+        dut_ip_str = f"{ip.dut.vendor}/{ip.dut.target_ip}"
+        common.info(f"Compiling Vivado Project DUT IP '{dut_ip_str}' ...")
+        est_time = get_ip_cmp_est(ip.dut.target_ip_model, sim_job)
+        if est_time > 0:
+            pool = ThreadPool(processes=1)
+            pool.apply_async(progress_bar)
+            eal.cmp_vivado_project(ip.dut.target_ip_model, sim_job, True, ip)
+            fill_progress_bar()
+            pool.terminate()
+            pool.join()
+        else:
+            eal.cmp_vivado_project(ip.dut.target_ip_model, sim_job)
     
     if sim_job.compile and sim_job.elaborate:
         if sim_job.simulator == common.simulators_enum.VIVADO:
@@ -226,7 +225,10 @@ def main(sim_job):
         if est_time > 0:
             pool = ThreadPool(processes=1)
             pool.apply_async(progress_bar)
-            eal.cmp_ip(ip, sim_job, fsoc_core_name, fsoc_core_flist_path)
+            if ip.vproj_name == "":
+                eal.cmp_ip(ip, sim_job, fsoc_core_name, fsoc_core_flist_path)
+            else:
+                eal.cmp_vivado_project(ip, sim_job)
             fill_progress_bar()
             pool.terminate()
             pool.join()
